herosdevices.interfaces.atomiq - Heros Devices 0.6.0 documentation

Skip to content
Back to top
View this page

# herosdevices.interfaces.atomiq

Translation/implementation interfaces for HEROized atomiq devices.

## Module Contents

class herosdevices.interfaces.atomiq.AtomiqInterface

  Bases: `herosdevices.interfaces.Interface`

  This interface defines the necessary methods for a HERO to seamlessly being converted into an atomiq component.

  The methods that need to be implemented are listed in the class-level list _atomiq_methods. If a subclass does not implement one of these methods a NotImplementedError is raised.

  Important: The methods given here are just the minimal set. Any other method of the atomiq component can be

    overloaded as well. In particular, if your hardware supports ramping or arbitrary functions, implement the ramp() and/or arb() methods in your subclass.

class herosdevices.interfaces.atomiq.Switch

  Bases: `AtomiqInterface`

  HERO implementation of `atomiq.components.primitives.Switchable`.

class herosdevices.interfaces.atomiq.Measurable

  Bases: `AtomiqInterface`

  HERO implementation of `atomiq.components.primitives.Measurable`.

class herosdevices.interfaces.atomiq.RFSource

  Bases: `AtomiqInterface`

  HERO implementation of `atomiq.components.electronics.rfsource.RFSource`.

  frequency: float = 1000000.0
  amplitude: float = 0.1
  phase: float = 0.0
  freq_max: float = 100000000.0
  freq_min: float = 100000.0
  amp_max: float = 1.0
  amp_min: float = 0.0
  default_ramp_steps: int = 30
  blind: bool = False

class herosdevices.interfaces.atomiq.VoltageSource

  Bases: `AtomiqInterface`

  HERO implementation of `atomiq.components.electronics.voltagesource.VoltageSource`.

  min_voltage: float
  max_voltage: float
  default_ramp_steps: int = 30
  blind: bool = False

class herosdevices.interfaces.atomiq.CurrentSource

  Bases: `AtomiqInterface`

  HERO implementation of `atomiq.components.electronics.currentsource.CurrentSource`.

  min_current: float
  max_current: float
  default_ramp_steps: int = 30
  blind: bool = False

class herosdevices.interfaces.atomiq.ADCChannel

  Bases: `AtomiqInterface`

  HERO implementation of `atomiq.components.electronics.adc.ADCChannel`.

class herosdevices.interfaces.atomiq.Camera

  Bases: `AtomiqInterface`

  HERO implementation of `atomiq.components.optoelectronics.camera.Camera`.